@@ -5,8 +5,10 @@ import (
 	"bytes"
 	"errors"
 	"io"
+	"os"
 	"os/exec"
 	"regexp"
+	"runtime"
 	"time"
 )
 
@@ -55,8 +57,19 @@ func (c conn) Start() error {
 
 // Close closes conn's WriteCloser, ReadClosers, and waits for the command to finish.
 func (c conn) Close() error {
+
 	writeErr := c.WriteCloser.Close()
 	readErr := c.readerCloser.Close()
+	var interruptErr error
+
+	if runtime.GOOS != "windows" {
+		// See https://github.com/bep/godartsass/issues/19
+		interruptErr = c.cmd.Process.Signal(os.Interrupt)
+		if interruptErr == os.ErrProcessDone {
+			interruptErr = nil
+		}
+	}
+
 	cmdErr := c.waitWithTimeout()
 
 	if writeErr != nil {
@@ -67,26 +80,34 @@ func (c conn) Close() error {
 		return readErr
 	}
 
+	if interruptErr != nil {
+		return interruptErr
+	}
+
 	return cmdErr
 }
 
 var brokenPipeRe = regexp.MustCompile("Broken pipe|pipe is being closed")
 
-// dart-sass-embedded ends on itself on EOF, this is just to give it some
+// dart-sass ends on itself on EOF, this is just to give it some
 // time to do so.
 func (c conn) waitWithTimeout() error {
 	result := make(chan error, 1)
 	go func() { result <- c.cmd.Wait() }()
 	select {
 	case err := <-result:
-		if _, ok := err.(*exec.ExitError); ok {
+		if eerr, ok := err.(*exec.ExitError); ok {
+			if eerr.Error() == "signal: interrupt" {
+				return nil
+			}
 			if brokenPipeRe.MatchString(c.stdErr.String()) {
 				return nil
 			}
+
 		}
 		return err
 	case <-time.After(5 * time.Second):
-		return errors.New("timed out waiting for dart-sass-embedded to finish")
+		return errors.New("timed out waiting for dart-sass to finish")
 	}
 }
 
