@@ -6,17 +6,17 @@ import (
 	"strings"
 	"time"
 
-	"github.com/bep/godartsass/internal/embeddedsassv1"
+	"github.com/bep/godartsass/v2/internal/embeddedsass"
 )
 
 // Options configures a Transpiler.
 type Options struct {
 	// The path to the Dart Sass wrapper binary, an absolute filename
 	// if not in $PATH.
-	// If this is not set, we will try 'dart-sass-embedded'
-	// (or 'dart-sass-embedded.bat' on Windows) in the OS $PATH.
+	// If this is not set, we will try 'dart-sass'
+	// (or 'dart-sass.bat' on Windows) in the OS $PATH.
 	// There may be several ways to install this, one would be to
-	// download it from here: https://github.com/sass/dart-sass-embedded/releases
+	// download it from here: https://github.com/sass/dart-sass/releases
 	DartSassEmbeddedFilename string
 
 	// Timeout is the duration allowed for dart sass to transpile.
@@ -54,7 +54,7 @@ type LogEvent struct {
 
 func (opts *Options) init() error {
 	if opts.DartSassEmbeddedFilename == "" {
-		opts.DartSassEmbeddedFilename = defaultDartSassEmbeddedFilename
+		opts.DartSassEmbeddedFilename = defaultDartSassBinaryFilename
 	}
 
 	if opts.Timeout == 0 {
@@ -102,7 +102,7 @@ type Args struct {
 	// See https://en.wikipedia.org/wiki/File_URI_scheme
 	//
 	// Note: There is an open issue for this value when combined with custom
-	// importers, see https://github.com/sass/dart-sass-embedded/issues/24
+	// importers, see https://github.com/sass/dart-sass/issues/24
 	URL string
 
 	// Defaults is SCSS.
@@ -124,11 +124,11 @@ type Args struct {
 	// Additional file paths to uses to resolve imports.
 	IncludePaths []string
 
-	sassOutputStyle  embeddedsassv1.OutputStyle
-	sassSourceSyntax embeddedsassv1.Syntax
+	sassOutputStyle  embeddedsass.OutputStyle
+	sassSourceSyntax embeddedsass.Syntax
 
 	// Ordered list starting with options.ImportResolver, then IncludePaths.
-	sassImporters []*embeddedsassv1.InboundMessage_CompileRequest_Importer
+	sassImporters []*embeddedsass.InboundMessage_CompileRequest_Importer
 }
 
 func (args *Args) init(seq uint32, opts Options) error {
@@ -139,23 +139,23 @@ func (args *Args) init(seq uint32, opts Options) error {
 		args.SourceSyntax = SourceSyntaxSCSS
 	}
 
-	v, ok := embeddedsassv1.OutputStyle_value[string(args.OutputStyle)]
+	v, ok := embeddedsass.OutputStyle_value[string(args.OutputStyle)]
 	if !ok {
 		return fmt.Errorf("invalid OutputStyle %q", args.OutputStyle)
 	}
-	args.sassOutputStyle = embeddedsassv1.OutputStyle(v)
+	args.sassOutputStyle = embeddedsass.OutputStyle(v)
 
-	v, ok = embeddedsassv1.Syntax_value[string(args.SourceSyntax)]
+	v, ok = embeddedsass.Syntax_value[string(args.SourceSyntax)]
 	if !ok {
 		return fmt.Errorf("invalid SourceSyntax %q", args.SourceSyntax)
 	}
 
-	args.sassSourceSyntax = embeddedsassv1.Syntax(v)
+	args.sassSourceSyntax = embeddedsass.Syntax(v)
 
 	if args.ImportResolver != nil {
-		args.sassImporters = []*embeddedsassv1.InboundMessage_CompileRequest_Importer{
+		args.sassImporters = []*embeddedsass.InboundMessage_CompileRequest_Importer{
 			{
-				Importer: &embeddedsassv1.InboundMessage_CompileRequest_Importer_ImporterId{
+				Importer: &embeddedsass.InboundMessage_CompileRequest_Importer_ImporterId{
 					ImporterId: seq,
 				},
 			},
@@ -164,7 +164,7 @@ func (args *Args) init(seq uint32, opts Options) error {
 
 	if args.IncludePaths != nil {
 		for _, p := range args.IncludePaths {
-			args.sassImporters = append(args.sassImporters, &embeddedsassv1.InboundMessage_CompileRequest_Importer{Importer: &embeddedsassv1.InboundMessage_CompileRequest_Importer_Path{
+			args.sassImporters = append(args.sassImporters, &embeddedsass.InboundMessage_CompileRequest_Importer{Importer: &embeddedsass.InboundMessage_CompileRequest_Importer_Path{
 				Path: filepath.Clean(p),
 			}})
 		}
